/*
 *  Copyright (c) 2009 Alessandro Pilotti
 *
 *  Permission is hereby granted, free of charge, to any person
 *  obtaining a copy of this software and associated documentation
 *  files (the "Software"), to deal in the Software without
 *  restriction, including without limitation the rights to use,
 *  copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the
 *  Software is furnished to do so, subject to the following
 *  conditions:
 *  
 *  The above copyright notice and this permission notice shall be
 *  included in all copies or substantial portions of the Software.
 *  
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 *  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 *  OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 *  NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 *  HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 *  WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 *  OTHER DEALINGS IN THE SOFTWARE.
 */

#pragma once

using namespace System;
using namespace System::Collections::Generic;
using namespace System::Runtime::InteropServices;

namespace AlexPilotti
{
	namespace OutlookAccountManager
	{
		public enum class AccountType { POP3, IMAP4, MAPI, Hotmail, LDAP };

		public enum class AccountCategory { Mail, AddressBook, Store };

		[Serializable]
		public ref class AccountData
		{
		public:

			property AccountType AccountType;

			property IList<AccountCategory>^ Categories;

			property unsigned int AccountID;
			property bool IsExchange; 

			property String^ AccountStamp;
			property String^ UserDisplayName; 
			property String^ AccountName;
			property String^ EmailID;
			property String^ SendStamp;
			property String^ AccountTypeDescription;
			property String^ ProfileName;

			property String^ IncomingServer; 
			property String^ OutgoingServer;
			property String^ IncomingLoginName;
			property String^ OutgoingLoginName; 

			property Nullable<unsigned> OutgoingServerAuthenticationType; 

			property Nullable<unsigned short> IncomingPort;
			property Nullable<unsigned short> OutgoingPort;

			property Nullable<bool> IncomingSSL;
			property Nullable<bool> OutgoingSSL;

			property Nullable<bool> IncomingSPA;
			property Nullable<bool> OutgoingSPA;

			property Nullable<bool> IncomingUseAuthentication;
			property Nullable<bool> OutgoingUseAuthentication;

			property Nullable<bool> IncomingRememberPassword;

			property Nullable<unsigned> TimeOut;

			property Nullable<unsigned> AccountFlags;

			property String^ ExchangeEmailID;
			property String^ ExchangeEmailID2;
			property String^ ExchangeServer;

			AccountData()
			{
				Categories = gcnew List<AccountCategory>();
			}
		};
	};
};